==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/FormatGroupTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatGroupTextEventArgsDescription } from "./FormatGroupTextEventArgsDescription";
/**
 * @hidden
 */
export let FormatGroupTextEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatGroupTextEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FormatGroupTextEventArgsDescriptionMetadata.a == null) {
                FormatGroupTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatGroupTextEventArgsDescriptionMetadata.c(FormatGroupTextEventArgsDescriptionMetadata.a);
            }
            if (a.k(FormatGroupTextEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(FormatGroupTextEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupName", "String");
            a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
            a.item("FormattedValue", "String");
            a.item("FormattedText", "String");
        }
        static d(a) {
            FormatGroupTextEventArgsDescriptionMetadata.b(a);
            a.ad("FormatGroupTextEventArgs", () => new FormatGroupTextEventArgsDescription());
            a.ac("FormatGroupTextEventArgs", FormatGroupTextEventArgsDescriptionMetadata.a);
        }
    }
    FormatGroupTextEventArgsDescriptionMetadata.$t = markType(FormatGroupTextEventArgsDescriptionMetadata, 'FormatGroupTextEventArgsDescriptionMetadata');
    FormatGroupTextEventArgsDescriptionMetadata.a = null;
    return FormatGroupTextEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/FormatGroupTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatGroupTextEventArgsDescription } from "./FormatGroupTextEventArgsDescription";
/**
 * @hidden
 */
export let FormatGroupTextEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatGroupTextEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FormatGroupTextEventArgsDescriptionMetadata.a == null) {
                FormatGroupTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatGroupTextEventArgsDescriptionMetadata.c(FormatGroupTextEventArgsDescriptionMetadata.a);
            }
            if (a.k(FormatGroupTextEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(FormatGroupTextEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupName", "String");
            a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
            a.item("FormattedValue", "String");
            a.item("FormattedText", "String");
        }
        static d(a) {
            FormatGroupTextEventArgsDescriptionMetadata.b(a);
            a.ae("FormatGroupTextEventArgs", () => new FormatGroupTextEventArgsDescription());
            a.ad("FormatGroupTextEventArgs", FormatGroupTextEventArgsDescriptionMetadata.a);
        }
    }
    FormatGroupTextEventArgsDescriptionMetadata.$t = markType(FormatGroupTextEventArgsDescriptionMetadata, 'FormatGroupTextEventArgsDescriptionMetadata');
    FormatGroupTextEventArgsDescriptionMetadata.a = null;
    return FormatGroupTextEventArgsDescriptionMetadata;
})();
